@@ -16,8 +16,6 @@ from __future__ import annotations
 
 from typing import Any
 from typing import NamedTuple
-from typing import Optional
-from typing import Union
 
 from enum import Enum
 from enum import IntEnum
@@ -42,6 +40,18 @@ class EncryptionData(NamedTuple):
     additional_data: Any = None
 
 
+class EncryptionInfoMsg(Enum):
+    BAD_OMEMO_CONFIG = _('This chat’s configuration is unsuitable for '
+                         'encryption with OMEMO. To use OMEMO in this chat, '
+                         'it should be non-anonymous and members-only.')
+    NO_FINGERPRINTS = _('To send an encrypted message, you have to decide '
+                        'whether to trust the device of your contact.')
+    QUERY_DEVICES = _('No devices found to encypt this message to. '
+                      'Querying for devices now…')
+    UNDECIDED_FINGERPRINTS = _('There are devices for which you have not made '
+                               'a trust decision yet.')
+
+
 class Entity(NamedTuple):
     jid: JID
     node: str
@@ -232,7 +242,7 @@ class XmppUriQuery(Enum):
     JOIN = 'join'
 
     @staticmethod
-    def from_str(s: str) -> Optional[XmppUriQuery]:
+    def from_str(s: str) -> XmppUriQuery | None:
         try:
             return XmppUriQuery(s)
         except ValueError:
@@ -912,7 +922,8 @@ COMMON_FEATURES = [
     Namespace.JINGLE_BYTESTREAM,
     Namespace.JINGLE_IBB,
     Namespace.AVATAR_METADATA + '+notify',
-    Namespace.MESSAGE_MODERATE
+    Namespace.MESSAGE_MODERATE,
+    Namespace.OMEMO_TEMP_DL + '+notify'
 ]
 
 
@@ -947,6 +958,7 @@ SHOW_STRING_MNEMONIC = {
 }
 
 GAJIM_FAQ_URI = 'https://dev.gajim.org/gajim/gajim/wikis/help/gajimfaq'
+GAJIM_PRIVACY_POLICY_URI = 'https://gajim.org/privacy/'
 GAJIM_WIKI_URI = 'https://dev.gajim.org/gajim/gajim/wikis'
 GAJIM_SUPPORT_JID = 'gajim@conference.gajim.org'
 
@@ -1008,14 +1020,21 @@ MIME_TYPES = (
     'audio/aac',
     'audio/ac3',
     'audio/flac',
+    'audio/mp3',
     'audio/mp4',
     'audio/mpeg',
     'audio/ogg',
     'audio/opus',
+    'audio/vnd.wave',
     'audio/wav',
+    'audio/wave',
+    'audio/x-aac',
     'audio/x-flac',
     'audio/x-m4a',
     'audio/x-matroska',
+    'audio/x-mp3',
+    'audio/x-mpeg',
+    'audio/x-ogg',
     'audio/x-wav',
     # font/*
     'font/ttf',
@@ -1106,7 +1125,7 @@ class PresenceShowExt(Enum):
     def is_offline(self):
         return self == PresenceShowExt.OFFLINE
 
-    def __lt__(self, other: Union[PresenceShowExt, PresenceShow]) -> bool:
+    def __lt__(self, other: PresenceShowExt | PresenceShow) -> bool:
         if isinstance(other, PresenceShowExt):
             return False
         if not isinstance(other, PresenceShow):  # pyright: ignore
