@@ -16,10 +16,9 @@ from __future__ import annotations
 
 import typing
 from typing import Any
-from typing import Callable
-from typing import Optional
 from typing import Union
 
+from collections.abc import Callable
 from dataclasses import dataclass
 from dataclasses import field
 
@@ -37,6 +36,7 @@ from nbxmpp.structs import ModerationData
 from nbxmpp.structs import RosterItem
 from nbxmpp.structs import TuneData
 
+from gajim.common.const import EncryptionInfoMsg
 from gajim.common.const import JingleState
 from gajim.common.const import KindConstant
 from gajim.common.file_props import FileProp
@@ -115,10 +115,17 @@ class Notification(ApplicationEvent):
     type: str
     title: str
     text: str
-    jid: Optional[Union[JID, str]] = None
-    sub_type: Optional[str] = None
-    sound: Optional[str] = None
-    icon_name: Optional[str] = None
+    jid: JID | str | None = None
+    sub_type: str | None = None
+    sound: str | None = None
+    icon_name: str | None = None
+
+
+@dataclass
+class ChatRead(ApplicationEvent):
+    name: str = field(init=False, default='chat-read')
+    account: str
+    jid: JID
 
 
 @dataclass
@@ -145,13 +152,13 @@ class SignedIn(ApplicationEvent):
 @dataclass
 class LocationChanged(ApplicationEvent):
     name: str = field(init=False, default='location-changed')
-    info: Optional[LocationData]
+    info: LocationData | None
 
 
 @dataclass
 class MusicTrackChanged(ApplicationEvent):
     name: str = field(init=False, default='music-track-changed')
-    info: Optional[TuneData]
+    info: TuneData | None
 
 
 @dataclass
@@ -161,12 +168,12 @@ class MessageSent(ApplicationEvent):
     jid: JID
     message: str
     message_id: str
-    msg_log_id: Optional[int]
-    chatstate: Optional[str]
+    msg_log_id: int | None
+    chatstate: str | None
     timestamp: float
     additional_data: AdditionalDataDict
-    label: Optional[SecurityLabel]
-    correct_id: Optional[str]
+    label: SecurityLabel | None
+    correct_id: str | None
     play_sound: bool
 
 
@@ -366,7 +373,7 @@ class MessageUpdated(ApplicationEvent):
     account: str
     jid: JID
     msgtxt: str
-    nickname: Optional[str]
+    nickname: str | None
     properties: Any
     correct_id: str
 
@@ -391,6 +398,10 @@ class MamMessageReceived(ApplicationEvent):
     stanza_id: str
     archive_jid: str
     kind: KindConstant
+    occupant_id: str | None
+    real_jid: JID | None
+    msg_log_id: int | None
+    displaymarking: Displaymarking | None
 
 
 @dataclass
@@ -407,15 +418,17 @@ class MessageReceived(ApplicationEvent):
     stanza_id: str
     fjid: str
     resource: str | None
-    delayed: Optional[float]
-    msg_log_id: Optional[int]
-    displaymarking: Optional[Displaymarking]
+    delayed: float | None
+    msg_log_id: int | None
+    displaymarking: Displaymarking | None
 
 
 @dataclass
 class GcMessageReceived(MessageReceived):
     name: str = field(init=False, default='gc-message-received')
     room_jid: str
+    real_jid: JID | None
+    occupant_id: str | None
 
 
 @dataclass
@@ -494,8 +507,8 @@ class CallUpdated(ApplicationEvent):
     jingle_type: str
     audio_state: JingleState
     video_state: JingleState
-    audio_sid: Optional[str]
-    video_sid: Optional[str]
+    audio_sid: str | None
+    video_sid: str | None
 
 
 @dataclass
@@ -556,7 +569,7 @@ class MucDecline(ApplicationEvent):
     account: str
     muc: JID
     from_: JID
-    reason: Optional[str]
+    reason: str | None
 
 
 @dataclass
@@ -566,11 +579,11 @@ class MucInvitation(ApplicationEvent):
     info: Any
     muc: JID
     from_: JID
-    reason: Optional[str]
-    password: Optional[str]
+    reason: str | None
+    password: str | None
     type: InviteType
     continued: bool
-    thread: Optional[str]
+    thread: str | None
 
 
 @dataclass
@@ -596,9 +609,6 @@ class PingReply(ApplicationEvent):
     seconds: float
 
 
-PingEventT = Union[PingSent, PingReply, PingError]
-
-
 @dataclass
 class SecCatalogReceived(ApplicationEvent):
     name: str = field(init=False, default='sec-catalog-received')
@@ -622,9 +632,8 @@ class PresenceReceived(ApplicationEvent):
     id_: str
     fjid: str
     timestamp: float
-    avatar_sha: Optional[str]
-    user_nick: Optional[str]
-    idle_time: Optional[float]
+    avatar_sha: str | None
+    user_nick: str | None
     show: str
     new_show: str
     old_show: str
@@ -710,24 +719,24 @@ class MUCRoomConfigFinished(ApplicationEvent):
 class MUCRoomPresenceError(ApplicationEvent):
     name: str = field(init=False, default='muc-room-presence-error')
     timestamp: float
-    error: Any
+    error: str
 
 
 @dataclass
 class MUCRoomKicked(ApplicationEvent):
     name: str = field(init=False, default='muc-room-kicked')
     timestamp: float
-    status_codes: Optional[set[StatusCode]]
-    reason: Optional[str]
-    actor: Optional[str]
+    status_codes: set[StatusCode] | None
+    reason: str | None
+    actor: str | None
 
 
 @dataclass
 class MUCRoomDestroyed(ApplicationEvent):
     name: str = field(init=False, default='muc-room-destroyed')
     timestamp: float
-    reason: Optional[str]
-    alternate: Optional[JID]
+    reason: str | None
+    alternate: JID | None
 
 
 @dataclass
@@ -736,7 +745,7 @@ class MUCUserJoined(ApplicationEvent):
     timestamp: float
     is_self: bool
     nick: str
-    status_codes: Optional[set[StatusCode]]
+    status_codes: set[StatusCode] | None
 
 
 @dataclass
@@ -745,9 +754,9 @@ class MUCUserLeft(ApplicationEvent):
     timestamp: float
     is_self: bool
     nick: str
-    status_codes: Optional[set[StatusCode]]
-    reason: Optional[str]
-    actor: Optional[str]
+    status_codes: set[StatusCode] | None
+    reason: str | None
+    actor: str | None
 
 
 @dataclass
@@ -757,8 +766,8 @@ class MUCUserRoleChanged(ApplicationEvent):
     is_self: bool
     nick: str
     role: Role
-    reason: Optional[str]
-    actor: Optional[str]
+    reason: str | None
+    actor: str | None
 
 
 @dataclass
@@ -768,8 +777,8 @@ class MUCUserAffiliationChanged(ApplicationEvent):
     is_self: bool
     nick: str
     affiliation: Affiliation
-    reason: Optional[str]
-    actor: Optional[str]
+    reason: str | None
+    actor: str | None
 
 
 @dataclass
@@ -780,3 +789,11 @@ class MUCUserStatusShowChanged(ApplicationEvent):
     nick: str
     status: str
     show_value: str
+
+
+@dataclass
+class EncryptionInfo(ApplicationEvent):
+    name: str = field(init=False, default='encryption-check')
+    account: str
+    jid: JID
+    message: EncryptionInfoMsg
