@@ -15,8 +15,10 @@
 from __future__ import annotations
 
 from typing import Any
+from typing import Literal
 from typing import overload
 
+import operator
 from collections.abc import Iterator
 from datetime import datetime
 from datetime import timezone
@@ -25,6 +27,7 @@ import cairo
 from gi.repository import GLib
 from nbxmpp.const import Affiliation
 from nbxmpp.const import Chatstate
+from nbxmpp.const import PresenceShow
 from nbxmpp.const import Role
 from nbxmpp.namespaces import Namespace
 from nbxmpp.protocol import JID
@@ -364,12 +367,18 @@ class BareContact(CommonContact):
         self._avatar_sha = app.storage.cache.get_contact(
             account, jid, 'avatar')
 
+        self._gateway_type: str | None = None
+
+        self._presence = UNKNOWN_PRESENCE
+
     @property
     def is_self(self):
         own_jid = app.get_client(self._account).get_own_jid().new_as_bare()
         return own_jid == self.jid
 
     def supports(self, requested_feature: str) -> bool:
+        if not self._resources:
+            return super().supports(requested_feature)
         return any(resource.supports(requested_feature)
                    for resource in self.iter_resources())
 
@@ -403,12 +412,22 @@ class BareContact(CommonContact):
         contact.connect('caps-update', self._on_signal)
         return contact
 
+    def has_resources(self) -> bool:
+        return bool(self._resources)
+
     def get_resource(self, resource: str) -> ResourceContact:
         contact = self._resources.get(resource)
         if contact is None:
             contact = self.add_resource(resource)
         return contact
 
+    def get_active_resource(self) -> ResourceContact | None:
+        if not self._resources:
+            return None
+
+        return sorted(self._resources.values(),
+                      key=operator.attrgetter('show'))[-1]
+
     def get_resources(self) -> list[ResourceContact]:
         resources: list[ResourceContact] = []
         for contact in self._resources.values():
@@ -423,16 +442,39 @@ class BareContact(CommonContact):
 
     @property
     def is_available(self) -> bool:
-        # pylint: disable=R1729
+        if not self._resources:
+            return self._presence.available
         return any(contact.is_available for contact
                    in self._resources.values())
 
     @property
-    def show(self):
-        show_values = [contact.show for contact in self._resources.values()]
-        if not show_values:
-            return PresenceShowExt.OFFLINE
-        return max(show_values)
+    def show(self) -> PresenceShow | Literal[PresenceShowExt.OFFLINE]:
+        if not self._resources:
+            if not self._presence.available:
+                return PresenceShowExt.OFFLINE
+            return self._presence.show
+
+        res = self.get_active_resource()
+        assert res is not None
+        return res.show
+
+    @property
+    def status(self) -> str:
+        if not self._resources:
+            return self._presence.status
+
+        res = self.get_active_resource()
+        assert res is not None
+        return res.status
+
+    @property
+    def idle_datetime(self) -> datetime | None:
+        if not self._resources:
+            return self._presence.idle_datetime
+
+        res = self.get_active_resource()
+        assert res is not None
+        return res.idle_datetime
 
     @property
     def chatstate(self) -> Chatstate | None:
@@ -477,6 +519,25 @@ class BareContact(CommonContact):
     def set_avatar_sha(self, sha: str) -> None:
         app.storage.cache.set_contact(self._account, self._jid, 'avatar', sha)
 
+    def _get_transport_icon_name(self) -> str | None:
+        if self._gateway_type is not None:
+            return f'gateway-{self._gateway_type}'
+
+        domain_disco = app.storage.cache.get_last_disco_info(self._jid.domain)
+        if domain_disco is None:
+            return None
+
+        if gateway_type := domain_disco.gateway_type:
+            self._gateway_type = gateway_type
+            return f'gateway-{gateway_type}'
+
+    def update_gateway_type(self, gateway_type: str | None):
+        if gateway_type == self._gateway_type:
+            return
+
+        self._gateway_type = gateway_type
+        self.notify('avatar-update')
+
     def get_avatar(self,
                    size: int,
                    scale: int,
@@ -486,22 +547,7 @@ class BareContact(CommonContact):
 
         show = self.show.value if add_show else None
 
-        transport_icon = None
-        if self.is_gateway:
-            disco_info = app.storage.cache.get_last_disco_info(self._jid)
-            if disco_info is not None:
-                if disco_info.gateway_type == 'sms':
-                    transport_icon = 'gajim-agent-sms'
-                if disco_info.gateway_type == 'irc':
-                    transport_icon = 'gajim-agent-irc'
-        else:
-            for resource_contact in self.iter_resources():
-                if resource_contact.identity_type == 'sms':
-                    transport_icon = 'gajim-agent-sms'
-                    break
-
-        if self.avatar_sha is not None:
-            transport_icon = None
+        transport_icon = self._get_transport_icon_name()
 
         return app.app.avatar_storage.get_surface(
             self,
@@ -513,8 +559,10 @@ class BareContact(CommonContact):
             style=style)
 
     def update_presence(self, presence_data: PresenceData) -> None:
-        for contact in self._resources.values():
-            contact.update_presence(presence_data, notify=False)
+        self._presence = presence_data
+        if not presence_data.available:
+            for contact in self._resources.values():
+                contact.update_presence(presence_data, notify=False)
         self.notify('presence-update')
 
     def update_avatar(self, sha: str) -> None:
@@ -589,6 +637,15 @@ class BareContact(CommonContact):
     def type_string(self) -> str:
         return 'chat'
 
+    @property
+    def is_bot(self) -> bool:
+        disco_info = app.storage.cache.get_last_disco_info(self._jid)
+
+        if disco_info is not None and disco_info.has_identity('client', 'bot'):
+            return True
+
+        return any(r.is_bot for r in self.iter_resources())
+
 
 class ResourceContact(CommonContact):
     def __init__(self, logger: LogAdapter, jid: JID, account: str) -> None:
@@ -627,6 +684,12 @@ class ResourceContact(CommonContact):
         return any(identity.type == 'phone' for
                    identity in disco_info.identities)
 
+    @property
+    def is_bot(self):
+        disco_info = app.storage.cache.get_last_disco_info(self._jid)
+        return (disco_info is not None
+                and disco_info.has_identity('client', 'bot'))
+
     @property
     def is_available(self) -> bool:
         return self._presence.available
@@ -646,8 +709,8 @@ class ResourceContact(CommonContact):
         return self._presence.priority
 
     @property
-    def idle_time(self) -> float | None:
-        return self._presence.idle_time
+    def idle_datetime(self) -> datetime | None:
+        return self._presence.idle_datetime
 
     @property
     def chatstate(self) -> Chatstate | None:
@@ -757,13 +820,13 @@ class GroupchatContact(CommonContact):
     def set_avatar_sha(self, sha: str) -> None:
         app.storage.cache.set_muc(self._account, self._jid, 'avatar', sha)
 
-    def get_avatar(self, size: int, scale: int) -> cairo.ImageSurface | None:
+    def get_avatar(self, size: int, scale: int) -> cairo.ImageSurface:
         transport_icon = None
         disco_info = self.get_disco()
         if disco_info is not None:
             for identity in disco_info.identities:
                 if identity.type == 'irc':
-                    transport_icon = 'gajim-agent-irc'
+                    transport_icon = 'gateway-irc'
                 break
         return app.app.avatar_storage.get_muc_surface(
             self._account,
@@ -854,6 +917,12 @@ class GroupchatContact(CommonContact):
     def type_string(self) -> str:
         return 'groupchat'
 
+    def has_composing_participants(self) -> bool:
+        return bool(self.get_module('Chatstate').get_composers(self._jid))
+
+    def get_composers(self) -> list['GroupchatParticipant']:
+        return self.get_module('Chatstate').get_composers(self._jid)
+
 
 class GroupchatParticipant(CommonContact):
     def __init__(self, logger: LogAdapter, jid: JID, account: str) -> None:
@@ -921,8 +990,8 @@ class GroupchatParticipant(CommonContact):
         return self._presence.status
 
     @property
-    def idle_time(self) -> float | None:
-        return self._presence.idle_time
+    def idle_datetime(self) -> datetime | None:
+        return self._presence.idle_datetime
 
     @property
     def name(self) -> str:
@@ -985,6 +1054,12 @@ class GroupchatParticipant(CommonContact):
     def occupant_id(self) -> str | None:
         return self._presence.occupant_id
 
+    @property
+    def is_self(self) -> bool:
+        data = self.get_module('MUC').get_muc_data(self.room.jid)
+        assert data is not None
+        return data.nick == self.name
+
 
 def can_add_to_roster(
     contact: BareContact | GroupchatContact | GroupchatParticipant
