@@ -17,7 +17,6 @@
 from __future__ import annotations
 
 from typing import Any
-from typing import Optional
 
 import time
 from datetime import datetime
@@ -136,7 +135,7 @@ class MAM(BaseModule):
 
     def _get_unique_id(self,
                        properties: MessageProperties
-                       ) -> tuple[Optional[str], Optional[str]]:
+                       ) -> tuple[str | None, str | None]:
         if properties.type.is_groupchat:
             return properties.mam.id, None
 
@@ -156,7 +155,7 @@ class MAM(BaseModule):
     @staticmethod
     def _get_stanza_id(properties: MessageProperties,
                        archive_jid: str
-                       ) -> Optional[StanzaIDData]:
+                       ) -> StanzaIDData | None:
         for stanza_id in properties.stanza_ids:
             if stanza_id.by == archive_jid:
                 return stanza_id
@@ -280,7 +279,6 @@ class MAM(BaseModule):
                 'retracted', 'reason', properties.moderation.reason)
 
             msgtxt = get_retraction_text(
-                self._account,
                 properties.moderation.moderator_jid,
                 properties.moderation.reason)
 
@@ -300,6 +298,13 @@ class MAM(BaseModule):
                 return
             stanza_id = message_id
 
+        occupant_id = self._get_occupant_id(properties)
+        real_jid = self._get_real_jid(properties)
+
+        displaymarking = None
+        if properties.has_security_label:
+            displaymarking = properties.security_label.displaymarking
+
         event_attr: dict[str, Any] = {
             'account': self._account,
             'jid': jid,
@@ -310,6 +315,9 @@ class MAM(BaseModule):
             'stanza_id': stanza_id,
             'archive_jid': properties.mam.archive,
             'kind': kind,
+            'occupant_id': occupant_id,
+            'real_jid': real_jid,
+            'displaymarking': displaymarking
         }
 
         if check_if_message_correction(properties,
@@ -321,7 +329,7 @@ class MAM(BaseModule):
                                        self._log):
             return
 
-        app.storage.archive.insert_into_logs(
+        event_attr['msg_log_id'] = app.storage.archive.insert_into_logs(
             self._account,
             jid,
             properties.mam.timestamp,
@@ -330,10 +338,35 @@ class MAM(BaseModule):
             contact_name=properties.muc_nickname,
             additional_data=additional_data,
             stanza_id=stanza_id,
-            message_id=properties.id)
+            message_id=properties.id,
+            occupant_id=occupant_id,
+            real_jid=real_jid,
+        )
 
         app.ged.raise_event(MamMessageReceived(**event_attr))
 
+    def _get_real_jid(self, properties: MessageProperties) -> JID | None:
+        if not properties.type.is_groupchat:
+            return None
+
+        if properties.muc_user is None:
+            return None
+
+        return properties.muc_user.jid
+
+    def _get_occupant_id(self, properties: MessageProperties) -> str | None:
+        if not properties.type.is_groupchat:
+            return None
+
+        if properties.occupant_id is None:
+            return None
+
+        contact = self._client.get_module('Contacts').get_contact(
+            properties.jid.bare, groupchat=True)
+        if contact.supports(Namespace.OCCUPANT_ID):
+            return properties.occupant_id
+        return None
+
     def _is_valid_request(self, properties: MessageProperties) -> bool:
         valid_id = self._mam_query_ids.get(properties.mam.archive, None)
         return valid_id == properties.mam.query_id
@@ -343,7 +376,7 @@ class MAM(BaseModule):
         self._mam_query_ids[jid] = query_id
         return query_id
 
-    def _get_query_params(self) -> tuple[Optional[str], Optional[datetime]]:
+    def _get_query_params(self) -> tuple[str | None, datetime | None]:
         own_jid = self._con.get_own_jid().bare
         archive = app.storage.archive.get_archive_infos(own_jid)
 
@@ -366,7 +399,7 @@ class MAM(BaseModule):
     def _get_muc_query_params(self,
                               jid: JID,
                               threshold: SyncThreshold
-                              ) -> tuple[Optional[str], Optional[datetime]]:
+                              ) -> tuple[str | None, datetime | None]:
 
         archive = app.storage.archive.get_archive_infos(jid)
         mam_id = None
@@ -464,12 +497,16 @@ class MAM(BaseModule):
         if threshold == SyncThreshold.NO_SYNC:
             return
 
+        contact = self._get_contact(jid, groupchat=True)
+        contact.notify('mam-sync-started')
+
         mam_id, start_date = self._get_muc_query_params(jid, threshold)
 
         result = yield self._execute_query(jid, mam_id, start_date)
         if is_error(result):
             if result.condition != 'item-not-found':
                 self._log.warning(result)
+                contact.notify('mam-sync-error', result.get_text())
                 return
 
             app.storage.archive.reset_archive_infos(result.jid)
@@ -477,6 +514,7 @@ class MAM(BaseModule):
             result = yield self._execute_query(result.jid, None, start_date)
             if is_error(result):
                 self._log.warning(result)
+                contact.notify('mam-sync-error', result.get_text())
                 return
 
         if result.rsm.last is not None:
@@ -488,11 +526,13 @@ class MAM(BaseModule):
                 last_mam_id=result.rsm.last,
                 last_muc_timestamp=time.time())
 
+        contact.notify('mam-sync-finished')
+
     @as_task
     def _execute_query(self,
                        jid: JID,
-                       mam_id: Optional[str],
-                       start_date: Optional[datetime]
+                       mam_id: str | None,
+                       start_date: datetime | None
                        ):
         _task = yield  # noqa: F841
 
@@ -532,8 +572,8 @@ class MAM(BaseModule):
     def request_archive_interval(self,
                                  start_date: datetime,
                                  end_date: datetime,
-                                 after: Optional[str] = None,
-                                 queryid: Optional[str] = None
+                                 after: str | None = None,
+                                 queryid: str | None = None
                                  ) -> str:
 
         jid = self._con.get_own_jid().bare
