@@ -14,14 +14,13 @@
 
 from __future__ import annotations
 
-from typing import Optional
-
 from enum import Enum
 from pathlib import Path
 
 from gi.repository import GObject
 from gi.repository import Gtk
 from gi.repository import Pango
+from nbxmpp.modules.dataforms import SimpleDataForm
 from nbxmpp.protocol import InvalidJid
 from nbxmpp.protocol import JID
 from nbxmpp.protocol import validate_resourcepart
@@ -30,6 +29,7 @@ from gajim.common import app
 from gajim.common import types
 from gajim.common.const import SimpleClientState
 from gajim.common.i18n import _
+from gajim.common.modules.contacts import BareContact
 from gajim.common.modules.contacts import GroupchatContact
 
 from gajim.gtk.dataform import DataFormWidget
@@ -66,13 +66,13 @@ class ChatFunctionPage(Gtk.Box):
         self.set_valign(Gtk.Align.CENTER)
         self.get_style_context().add_class('padding-18')
 
-        self._client: Optional[types.Client] = None
-        self._contact: Optional[types.ChatContactT] = None
-        self._mode: Optional[FunctionMode] = None
-        self._data: Optional[str] = None
+        self._client: types.Client | None = None
+        self._contact: types.ChatContactT | None = None
+        self._mode: FunctionMode | None = None
+        self._data: str | None = None
         self._ready_state = True
 
-        self._widget: Optional[Gtk.Widget] = None
+        self._widget: Gtk.Widget | None = None
 
         self._heading = Gtk.Label()
         self._heading.set_max_width_chars(30)
@@ -136,8 +136,8 @@ class ChatFunctionPage(Gtk.Box):
     def set_mode(self,
                  contact: types.ChatContactT,
                  mode: FunctionMode,
-                 data: Optional[str] = None,
-                 files: Optional[list[str]] = None
+                 data: str | None = None,
+                 files: list[str] | None = None
                  ) -> None:
 
         self._reset()
@@ -204,7 +204,9 @@ class ChatFunctionPage(Gtk.Box):
                 'suggested-action')
             muc_data = self._client.get_module('MUC').get_muc_data(
                 self._contact.jid)
+            assert muc_data is not None
             form = muc_data.captcha_form
+            assert form is not None
             options = {'no-scrolling': True,
                        'entry-activates-default': True}
             self._widget = DataFormWidget(form, options=options)
@@ -238,6 +240,8 @@ class ChatFunctionPage(Gtk.Box):
             self._widget.focus()
         elif isinstance(self._widget, DataFormWidget):
             self._widget.focus_first_entry()
+        elif mode == FunctionMode.SEND_FILE:
+            self._confirm_button.grab_focus()
 
     def _on_client_state_changed(self,
                                  _client: types.Client,
@@ -311,6 +315,7 @@ class ChatFunctionPage(Gtk.Box):
         elif self._mode == FunctionMode.CAPTCHA_REQUEST:
             assert isinstance(self._widget, DataFormWidget)
             form_node = self._widget.get_submit_form()
+            assert isinstance(form_node, SimpleDataForm)
             self._client.get_module('MUC').send_captcha(
                 self._contact.jid, form_node)
 
@@ -360,6 +365,7 @@ class ChatFunctionPage(Gtk.Box):
             self._contact.jid, invited_jid)
         invited_contact = client.get_module('Contacts').get_contact(
             invited_jid)
+        assert isinstance(invited_contact, BareContact)
         self.emit(
             'message',
             _('%s has been invited to this group chat') % invited_contact.name)
@@ -392,7 +398,7 @@ class InputWidget(Gtk.Box):
     def __init__(self,
                  contact: types.ChatContactT,
                  mode: FunctionMode,
-                 data: Optional[str] = None
+                 data: str | None = None
                  ) -> None:
 
         Gtk.Box.__init__(self,
@@ -468,8 +474,8 @@ class InputWidget(Gtk.Box):
 
 class ErrorWidget(Gtk.Box):
     def __init__(self,
-                 mode: Optional[FunctionMode] = None,
-                 error_text: Optional[str] = None
+                 mode: FunctionMode | None = None,
+                 error_text: str | None = None
                  ) -> None:
 
         Gtk.Box.__init__(self,
