@@ -16,8 +16,6 @@ from __future__ import annotations
 
 from typing import Any
 from typing import cast
-from typing import Optional
-from typing import Union
 
 import logging
 import time
@@ -43,9 +41,9 @@ from gajim.gtk.util import EventHelper
 
 log = logging.getLogger('gajim.gtk.chatlist')
 
-MessageEventT = Union[events.MessageReceived,
-                      events.GcMessageReceived,
-                      events.MamMessageReceived]
+MessageEventT = (events.MessageReceived |
+                 events.GcMessageReceived |
+                 events.MamMessageReceived)
 
 
 class ChatList(Gtk.ListBox, EventHelper):
@@ -61,7 +59,7 @@ class ChatList(Gtk.ListBox, EventHelper):
         EventHelper.__init__(self)
         self._workspace_id = workspace_id
 
-        self._chats: dict[tuple[str, JID], Any] = {}
+        self._chats: dict[tuple[str, JID], ChatListRow] = {}
         self._current_filter: str = 'all'
         self._current_filter_text: str = ''
 
@@ -71,7 +69,10 @@ class ChatList(Gtk.ListBox, EventHelper):
         self.set_sort_func(self._sort_func)
         self._set_placeholder()
 
-        self._mouseover: bool = False
+        self._rows_need_sort = False
+        self._context_menu_visible = False
+        self._mouseover = False
+        self._pinned_order_change = False
         self.connect('enter-notify-event', self._on_mouse_focus_changed)
         self.connect('leave-notify-event', self._on_mouse_focus_changed)
 
@@ -85,7 +86,7 @@ class ChatList(Gtk.ListBox, EventHelper):
             entries,
             Gdk.DragAction.MOVE)
 
-        self._drag_row: Optional[ChatListRow] = None
+        self._drag_row: ChatListRow | None = None
         self._chat_order: list[ChatListRow] = []
 
         self.register_events([
@@ -97,7 +98,7 @@ class ChatList(Gtk.ListBox, EventHelper):
         self.connect('drag-data-received', self._on_drag_data_received)
         self.connect('destroy', self._on_destroy)
 
-        self._timer_id = GLib.timeout_add_seconds(60, self._update_time)
+        self._timer_id = GLib.timeout_add_seconds(60, self._update_row_state)
 
         self.show_all()
 
@@ -112,7 +113,7 @@ class ChatList(Gtk.ListBox, EventHelper):
                               account: str,
                               jid: JID,
                               include_silent: bool = False
-                              ) -> Optional[int]:
+                              ) -> int | None:
         chat = self._chats.get((account, jid))
         if chat is not None:
             if include_silent:
@@ -137,13 +138,13 @@ class ChatList(Gtk.ListBox, EventHelper):
         self._current_filter_text = text
         self.invalidate_filter()
 
-    def get_chat_type(self, account: str, jid: JID) -> Optional[str]:
+    def get_chat_type(self, account: str, jid: JID) -> str | None:
         row = self._chats.get((account, jid))
         if row is not None:
             return row.type
         return None
 
-    def get_selected_chat(self) -> Optional[ChatListRow]:
+    def get_selected_chat(self) -> ChatListRow | None:
         row = cast(ChatListRow | None, self.get_selected_row())
         if row is None:
             return None
@@ -162,8 +163,9 @@ class ChatList(Gtk.ListBox, EventHelper):
 
     def mark_as_read(self, account: str, jid: JID) -> None:
         chat = self._chats.get((account, jid))
-        if chat is not None:
+        if chat is not None and chat.get_real_unread_count() > 0:
             chat.reset_unread()
+            app.ged.raise_event(events.ChatRead(account=account, jid=jid))
 
     def toggle_chat_pinned(self, account: str, jid: JID) -> None:
         row = self._chats[(account, jid)]
@@ -204,6 +206,8 @@ class ChatList(Gtk.ListBox, EventHelper):
 
         row.connect('drag-begin', self._on_row_drag_begin)
         row.connect('unread-changed', self._on_row_unread_changed)
+        row.connect('context-menu-state-changed',
+                    self._on_context_menu_state_changed)
 
         self.add(row)
 
@@ -301,12 +305,17 @@ class ChatList(Gtk.ListBox, EventHelper):
             self.remove_chat(account, jid)
         self._emit_unread_changed()
 
+    def clear_chat_list_row(self, account: str, jid: JID) -> None:
+        chat = self._chats.get((account, jid))
+        if chat is not None:
+            chat.clear()
+
     def contains_chat(self, account: str, jid: JID) -> bool:
         return self._chats.get((account, jid)) is not None
 
     def process_event(self, event: events.ChatListEventT) -> None:
-        if isinstance(event, (events.MessageReceived,
-                              events.MamMessageReceived,
+        if isinstance(event, (events.MessageReceived |
+                              events.MamMessageReceived |
                               events.GcMessageReceived)):
             self._on_message_received(event)
         elif isinstance(event, events.MessageUpdated):
@@ -341,13 +350,13 @@ class ChatList(Gtk.ListBox, EventHelper):
                        self._workspace_id,
                        count)
 
-    def _get_row_before(self, row: ChatListRow) -> Optional[ChatListRow]:
+    def _get_row_before(self, row: ChatListRow) -> ChatListRow | None:
         row_before = self.get_row_at_index(row.get_index() - 1)
         if row_before is None:
             return
         return cast(ChatListRow, row_before)
 
-    def _get_row_after(self, row: ChatListRow) -> Optional[ChatListRow]:
+    def _get_row_after(self, row: ChatListRow) -> ChatListRow | None:
         row_after = self.get_row_at_index(row.get_index() + 1)
         if row_after is None:
             return
@@ -369,6 +378,14 @@ class ChatList(Gtk.ListBox, EventHelper):
     def _on_row_unread_changed(self, row: ChatListRow) -> None:
         self._emit_unread_changed()
 
+    def _on_context_menu_state_changed(self,
+                                       row: ChatListRow,
+                                       menu_is_visible: bool
+                                       ) -> None:
+
+        self._context_menu_visible = menu_is_visible
+        self._schedule_check_sort_inhibit()
+
     def _on_drag_data_received(self,
                                _widget: Gtk.Widget,
                                _drag_context: Gdk.DragContext,
@@ -416,7 +433,7 @@ class ChatList(Gtk.ListBox, EventHelper):
 
         self._change_pinned_order(row_before)
 
-    def _change_pinned_order(self, row_before: Optional[ChatListRow]) -> None:
+    def _change_pinned_order(self, row_before: ChatListRow | None) -> None:
         assert self._drag_row is not None
 
         self._chat_order.remove(self._drag_row)
@@ -434,11 +451,13 @@ class ChatList(Gtk.ListBox, EventHelper):
             row.position = self._chat_order.index(row)
 
         self.emit('chat-order-changed')
+        self._pinned_order_change = True
         self.invalidate_sort()
+        self._pinned_order_change = False
 
-    def _update_time(self) -> bool:
-        for _key, row in self._chats.items():
-            row.update_time()
+    def _update_row_state(self) -> bool:
+        for row in self._chats.values():
+            row.update_state()
         return True
 
     def _filter_func(self, row: ChatListRow) -> bool:
@@ -474,8 +493,9 @@ class ChatList(Gtk.ListBox, EventHelper):
                     row.set_header_type(None)
 
     def _sort_func(self, row1: ChatListRow, row2: ChatListRow) -> int:
-        if self._mouseover:
-            log.debug('Mouseover active, don’t sort rows')
+        if self._is_sort_inhibited():
+            self._rows_need_sort = True
+            log.debug('Sort inhibited')
             return 0
 
         # Sort pinned rows according to stored order
@@ -493,6 +513,33 @@ class ChatList(Gtk.ListBox, EventHelper):
         # Sort by timestamp
         return -1 if row1.timestamp > row2.timestamp else 1
 
+    def invalidate_sort(self) -> None:
+        if self._is_sort_inhibited():
+            return
+
+        self._rows_need_sort = False
+        log.debug('Sort Chatlist')
+        Gtk.ListBox.invalidate_sort(self)
+
+    def _is_sort_inhibited(self) -> bool:
+        if self._pinned_order_change:
+            return False
+        return self._mouseover or self._context_menu_visible
+
+    def _schedule_check_sort_inhibit(self) -> None:
+        if self._is_sort_inhibited():
+            return
+        GLib.timeout_add(100, self._check_sort_inhibit)
+
+    def _check_sort_inhibit(self) -> None:
+        if self._is_sort_inhibited():
+            return
+
+        if not self._rows_need_sort:
+            return
+
+        self.invalidate_sort()
+
     def _on_mouse_focus_changed(self,
                                 _widget: Gtk.ListBox,
                                 event: Gdk.EventCrossing
@@ -506,6 +553,8 @@ class ChatList(Gtk.ListBox, EventHelper):
                 # Not hovering a Gtk.ListBoxRow (row is INFERIOR)
                 self._mouseover = False
 
+        self._schedule_check_sort_inhibit()
+
     @staticmethod
     def _on_start_chat_clicked(_button: Gtk.Button) -> None:
         app.app.activate_action('start-chat', GLib.Variant('as', ['', '']))
@@ -588,7 +637,6 @@ class ChatList(Gtk.ListBox, EventHelper):
 
         if event.moderation.stanza_id == row.stanza_id:
             text = get_retraction_text(
-                event.account,
                 event.moderation.moderator_jid,
                 event.moderation.reason)
             row.set_message_text(text)
