@@ -15,8 +15,6 @@
 from __future__ import annotations
 
 from typing import cast
-from typing import Optional
-from typing import Union
 
 import logging
 from enum import IntEnum
@@ -33,7 +31,9 @@ from nbxmpp.task import Task
 
 from gajim.common import app
 from gajim.common import ged
+from gajim.common import types
 from gajim.common.const import AvatarSize
+from gajim.common.const import SimpleClientState
 from gajim.common.events import SubscribedPresenceReceived
 from gajim.common.events import UnsubscribedPresenceReceived
 from gajim.common.ged import EventHelper
@@ -49,6 +49,7 @@ from gajim.gtk.builder import get_builder
 from gajim.gtk.contact_settings import ContactSettings
 from gajim.gtk.dialogs import ConfirmationDialog
 from gajim.gtk.dialogs import DialogButton
+from gajim.gtk.omemo_trust_manager import OMEMOTrustManager
 from gajim.gtk.sidebar_switcher import SideBarSwitcher
 from gajim.gtk.structs import RemoveHistoryActionParams
 from gajim.gtk.util import connect_destroy
@@ -57,7 +58,7 @@ from gajim.gtk.vcard_grid import VCardGrid
 log = logging.getLogger('gajim.gtk.contact_info')
 
 
-ContactT = Union[BareContact, GroupchatParticipant]
+ContactT = BareContact | GroupchatParticipant
 
 
 class Column(IntEnum):
@@ -69,7 +70,7 @@ class ContactInfo(Gtk.ApplicationWindow, EventHelper):
     def __init__(self,
                  account: str,
                  contact: ContactT,
-                 page: Optional[str] = None) -> None:
+                 page: str | None = None) -> None:
 
         Gtk.ApplicationWindow.__init__(self)
         EventHelper.__init__(self)
@@ -86,6 +87,8 @@ class ContactInfo(Gtk.ApplicationWindow, EventHelper):
         self.account = account
         self.contact = contact
         self._client = app.get_client(account)
+        self._client.connect_signal(
+            'state-changed', self._on_client_state_changed)
 
         self._ui = get_builder('contact_info.ui')
 
@@ -108,6 +111,7 @@ class ContactInfo(Gtk.ApplicationWindow, EventHelper):
 
         if isinstance(self.contact, BareContact):
             self._fill_settings_page(self.contact)
+            self._fill_encryption_page(self.contact)
             self._fill_device_info(self.contact)
             self._fill_groups_page(self.contact)
             self._fill_note_page(self.contact)
@@ -119,7 +123,6 @@ class ContactInfo(Gtk.ApplicationWindow, EventHelper):
         self.connect('key-press-event', self._on_key_press)
         self.connect('destroy', self._on_destroy)
 
-        # pylint: disable=line-too-long
         connect_destroy(self._ui.tree_selection,
                         'changed', self._on_group_selection_changed)
         connect_destroy(self._ui.toggle_renderer,
@@ -133,7 +136,6 @@ class ContactInfo(Gtk.ApplicationWindow, EventHelper):
             ('unsubscribed-presence-received', ged.GUI1,
              self._on_unsubscribed_presence_received),
         ])
-        # pylint: enable=line-too-long
 
         self.add(self._ui.main_grid)
         self.show_all()
@@ -142,6 +144,24 @@ class ContactInfo(Gtk.ApplicationWindow, EventHelper):
         if event.keyval == Gdk.KEY_Escape:
             self.destroy()
 
+    def _on_client_state_changed(self,
+                                 _client: types.Client,
+                                 _signal_name: str,
+                                 state: SimpleClientState
+                                 ) -> None:
+
+        self._ui.edit_name_button.set_sensitive(state.is_connected)
+        self._ui.edit_name_button.set_tooltip_text(
+            _('Not connected') if not state.is_connected else _('Edit Name…'))
+        self._ui.subscription_listbox.set_sensitive(state.is_connected)
+
+        if state.is_connected:
+            self._ui.groups_page_stack.set_visible_child_name('groups')
+            self._ui.notes_page_stack.set_visible_child_name('notes')
+        else:
+            self._ui.groups_page_stack.set_visible_child_name('offline')
+            self._ui.notes_page_stack.set_visible_child_name('offline')
+
     def _on_stack_child_changed(self,
                                 _widget: Gtk.Stack,
                                 _pspec: GObject.ParamSpec) -> None:
@@ -153,7 +173,7 @@ class ContactInfo(Gtk.ApplicationWindow, EventHelper):
         for task in self._tasks:
             task.cancel()
 
-        if self.contact.is_in_roster:
+        if self.contact.is_in_roster and self._client.state.is_available:
             self._save_annotation()
 
         for device_grid in self._devices.values():
@@ -166,13 +186,17 @@ class ContactInfo(Gtk.ApplicationWindow, EventHelper):
     def _fill_information_page(self, contact: ContactT) -> None:
         self._vcard_grid = VCardGrid(self.account)
         self._ui.vcard_box.add(self._vcard_grid)
-        self._client.get_module('VCard4').request_vcard(
-            jid=self.contact.jid,
-            callback=self._on_vcard_received)
+        if self._client.state.is_available:
+            self._client.get_module('VCard4').request_vcard(
+                jid=self.contact.jid,
+                callback=self._on_vcard_received)
 
         jid = str(contact.get_address())
 
         self._ui.contact_name_label.set_text(contact.name)
+        self._ui.edit_name_button.set_sensitive(
+            self._client.state.is_available)
+
         self._ui.contact_jid_label.set_text(jid)
         self._ui.contact_jid_label.set_tooltip_text(jid)
 
@@ -184,6 +208,11 @@ class ContactInfo(Gtk.ApplicationWindow, EventHelper):
 
         self._switcher.set_row_visible('information', True)
 
+    def _fill_encryption_page(self, contact: ContactT) -> None:
+        self._ui.encryption_box.add(
+            OMEMOTrustManager(self.contact.account, self.contact))
+        self._switcher.set_row_visible('encryption-omemo', True)
+
     def _fill_note_page(self, contact: BareContact) -> None:
         if not contact.is_in_roster:
             return
@@ -205,6 +234,9 @@ class ContactInfo(Gtk.ApplicationWindow, EventHelper):
 
         self._ui.from_subscription_switch.set_state(contact.is_subscribed)
 
+        self._ui.subscription_listbox.set_sensitive(
+            self._client.state.is_available)
+
         if contact.subscription in ('to', 'both'):
             self._ui.to_subscription_stack.set_visible_child_name('checkmark')
 
@@ -226,7 +258,7 @@ class ContactInfo(Gtk.ApplicationWindow, EventHelper):
             params.to_variant())
 
     def _fill_groups_page(self, contact: BareContact) -> None:
-        if not contact.is_in_roster:
+        if not contact.is_in_roster or not self._client.state.is_available:
             return
 
         model = self._ui.groups_treeview.get_model()
@@ -269,9 +301,12 @@ class ContactInfo(Gtk.ApplicationWindow, EventHelper):
 
     def _on_vcard_received(self, task: Task) -> None:
         try:
-            vcard = cast(VCard, task.finish())
+            vcard = cast(VCard | None, task.finish())
         except StanzaError as err:
             log.info('Error loading VCard: %s', err)
+            vcard = None
+
+        if vcard is None:
             vcard = VCard()
 
         self._vcard_grid.set_vcard(vcard)
@@ -502,7 +537,7 @@ class DeviceGrid:
     def widget(self) -> Gtk.Grid:
         return self._ui.devices_grid
 
-    def set_entity_time(self, entity_time: Optional[str]) -> None:
+    def set_entity_time(self, entity_time: str | None) -> None:
         if entity_time is not None:
             self._ui.time_value.set_text(entity_time)
             self._ui.time_value.show()
@@ -510,7 +545,7 @@ class DeviceGrid:
 
         self._check_complete()
 
-    def set_software(self, software: Optional[SoftwareVersionResult]) -> None:
+    def set_software(self, software: SoftwareVersionResult | None) -> None:
         if software is not None:
             software_string = f'{software.name} {software.version}'
             self._ui.software_value.set_text(software_string)
