@@ -14,9 +14,6 @@
 
 from __future__ import annotations
 
-from typing import Optional
-from typing import Union
-
 import textwrap
 from datetime import datetime
 from datetime import timedelta
@@ -42,6 +39,7 @@ from gajim.common.i18n import _
 from gajim.common.i18n import is_rtl_text
 from gajim.common.modules.contacts import GroupchatContact
 from gajim.common.modules.contacts import GroupchatParticipant
+from gajim.common.modules.contacts import ResourceContact
 from gajim.common.types import ChatContactT
 
 from gajim.gtk.conversation.message_widget import MessageWidget
@@ -63,17 +61,17 @@ class MessageRow(BaseRow):
     def __init__(self,
                  account: str,
                  contact: ChatContactT,
-                 message_id: Optional[str],
-                 stanza_id: Optional[str],
+                 message_id: str | None,
+                 stanza_id: str | None,
                  timestamp: float,
                  kind: str,
                  name: str,
                  text: str,
-                 additional_data: Optional[AdditionalDataDict] = None,
-                 display_marking: Optional[Displaymarking] = None,
-                 marker: Optional[str] = None,
-                 error: Union[CommonError, StanzaError, None] = None,
-                 log_line_id: Optional[int] = None) -> None:
+                 additional_data: AdditionalDataDict | None = None,
+                 display_marking: Displaymarking | None = None,
+                 marker: str | None = None,
+                 error: CommonError | StanzaError | None = None,
+                 log_line_id: int | None = None) -> None:
 
         BaseRow.__init__(self, account)
         self.type = 'chat'
@@ -109,16 +107,10 @@ class MessageRow(BaseRow):
         else:
             from_us = kind == 'outgoing'
 
-        is_previewable = False
-        preview_enabled = app.settings.get('enable_file_preview')
-        if additional_data is not None and preview_enabled:
-            is_previewable = app.preview_manager.is_previewable(
-                text, additional_data)
-
-        if is_previewable:
+        if app.preview_manager.is_previewable(text, additional_data):
             muc_context = None
             if isinstance(self._contact,
-                          (GroupchatContact, GroupchatParticipant)):
+                          GroupchatContact | GroupchatParticipant):
                 muc_context = self._contact.muc_context
             self._message_widget = PreviewWidget(account)
             app.preview_manager.create_preview(
@@ -219,7 +211,7 @@ class MessageRow(BaseRow):
             self._message_widget.set_selectable(True)
 
     def _add_security_label(self,
-                            display_marking: Optional[Displaymarking]
+                            display_marking: Displaymarking | None
                             ) -> None:
 
         if display_marking is None:
@@ -256,7 +248,7 @@ class MessageRow(BaseRow):
             self.get_style_context().add_class(
                 'gajim-mention-highlight')
 
-    def _get_avatar(self, kind: str, name: str) -> Optional[cairo.ImageSurface]:
+    def _get_avatar(self, kind: str, name: str) -> cairo.ImageSurface | None:
         scale = self.get_scale_factor()
         if isinstance(self._contact, GroupchatContact):
             contact = self._contact.get_resource(name)
@@ -268,6 +260,7 @@ class MessageRow(BaseRow):
         else:
             contact = self._contact
 
+        assert not isinstance(contact, GroupchatContact | ResourceContact)
         avatar = contact.get_avatar(AvatarSize.ROSTER, scale, add_show=False)
         assert not isinstance(avatar, GdkPixbuf.Pixbuf)
         return avatar
@@ -321,7 +314,7 @@ class MessageRow(BaseRow):
 
     def _get_encryption_image(self,
                               additional_data: AdditionalDataDict,
-                              ) -> Optional[Gtk.Image]:
+                              ) -> Gtk.Image | None:
 
         details = self._get_encryption_details(additional_data)
         if details is None:
@@ -352,9 +345,10 @@ class MessageRow(BaseRow):
         return image
 
     @staticmethod
-    def _get_encryption_details(additional_data: AdditionalDataDict
-                                ) -> Optional[tuple[
-                                    str, Optional[str], Optional[Trust]]]:
+    def _get_encryption_details(
+        additional_data: AdditionalDataDict
+    ) -> tuple[str, str | None, Trust | None] | None:
+
         name = additional_data.get_value('encrypted', 'name')
         if name is None:
             return None
@@ -396,7 +390,7 @@ class MessageRow(BaseRow):
         self._message_widget.add_with_styling(text)
         self.get_style_context().add_class('retracted-message')
 
-    def set_correction(self, text: str, nickname: Optional[str]) -> None:
+    def set_correction(self, text: str, nickname: str | None) -> None:
         if not isinstance(self._message_widget, PreviewWidget):
             self._message_widget.add_with_styling(text, nickname)
 
