@@ -108,6 +108,13 @@ class CSSConfig:
             self._dynamic_provider,
             CSSPriority.APPLICATION)
 
+        # Font size provider for GUI font size
+        self._app_font_size_provider = Gtk.CssProvider()
+        Gtk.StyleContext.add_provider_for_screen(
+            screen,
+            self._app_font_size_provider,
+            CSSPriority.PRE_APPLICATION)
+
         # Cache of recently requested values
         self._cache: dict[str, str | Pango.FontDescription | None] = {}
 
@@ -128,8 +135,7 @@ class CSSConfig:
             self._provider,
             CSSPriority.USER_THEME)
 
-        if sys.platform == 'win32':
-            self._apply_windows_font_size()
+        self.apply_app_font_size()
 
     @property
     def prefer_dark(self) -> bool:
@@ -197,20 +203,14 @@ class CSSConfig:
         except Exception:
             log.exception('Error loading application css')
 
-    @staticmethod
-    def _apply_windows_font_size() -> None:
-        css = '''
-        * {
-            font-size: 1.125rem;
-        }
+    def apply_app_font_size(self) -> None:
+        app_font_size = app.settings.get('app_font_size')
+        css = f'''
+        * {{
+            font-size: {app_font_size}rem;
+        }}
         '''
-        provider = Gtk.CssProvider()
-        provider.load_from_data(bytes(css.encode('utf-8')))
-        screen = Gdk.Screen.get_default()
-        assert screen is not None
-        Gtk.StyleContext.add_provider_for_screen(screen,
-                                                 provider,
-                                                 CSSPriority.PRE_APPLICATION)
+        self._app_font_size_provider.load_from_data(bytes(css.encode('utf-8')))
 
     @staticmethod
     def _pango_to_css_weight(number: int) -> int:
@@ -342,7 +342,9 @@ class CSSConfig:
             if rule.selectorText == selector:
                 log.info('Set Font for: %s %s %s %s %s',
                          selector, family, size, style, weight)
-                rule.style['font-family'] = family
+                # Quote font-family in order to avoid unquoted font-families
+                # (this is a bug in css_parser)
+                rule.style['font-family'] = f'"{family}"'
                 rule.style['font-style'] = style
                 rule.style['font-size'] = f'{size}pt'
                 rule.style['font-weight'] = weight
@@ -357,7 +359,9 @@ class CSSConfig:
         log.info('Set Font for: %s %s %s %s %s',
                  selector, family, size, style, weight)
         rule = CSSStyleRule(selectorText=selector)
-        rule.style['font-family'] = family
+        # Quote font-family in order to avoid unquoted font-families
+        # (this is a bug in css_parser)
+        rule.style['font-family'] = f'"{family}"'
         rule.style['font-style'] = style
         rule.style['font-size'] = f'{size}pt'
         rule.style['font-weight'] = weight
@@ -416,6 +420,11 @@ class CSSConfig:
                 weight = rule.style.getPropertyValue('font-weight') or None
                 family = rule.style.getPropertyValue('font-family') or None
 
+                if family is not None:
+                    # Unquote previously quoted font-family
+                    # (this is a bug in css_parser)
+                    family = family.strip('"')
+
                 desc = self._get_description_from_css(
                     family, size, style, weight)
                 if not pre:
@@ -441,7 +450,7 @@ class CSSConfig:
         if style is not None:
             desc.set_style(self._get_pango_style_from_string(style))
         if size is not None:
-            desc.set_size(int(size[:-2]) * Pango.SCALE)
+            desc.set_size(int(float(size[:-2])) * Pango.SCALE)
         return desc
 
     @staticmethod
