@@ -12,6 +12,7 @@
 # You should have received a copy of the GNU General Public License
 # along with Gajim. If not, see <http://www.gnu.org/licenses/>.
 
+from __future__ import annotations
 
 import logging
 import time
@@ -32,6 +33,7 @@ from gajim.common.helpers import get_groupchat_name
 from gajim.common.helpers import open_uri
 from gajim.common.i18n import _
 from gajim.common.i18n import p_
+from gajim.common.modules.contacts import GroupchatContact
 
 from gajim.gtk.builder import get_builder
 from gajim.gtk.util import make_href_markup
@@ -49,12 +51,12 @@ MUC_FEATURES = {
         _('This group chat is restricted '
           'to members only')),
     'muc_nonanonymous': (
-        'feather-shield-off-symbolic',
+        'feather-eye-symbolic',
         p_('Group chat feature', 'Not Anonymous'),
         _('All other group chat participants '
           'can see your XMPP address')),
     'muc_semianonymous': (
-        'feather-shield-symbolic',
+        'feather-eye-off-symbolic',
         p_('Group chat feature', 'Semi-Anonymous'),
         _('Only moderators can see your XMPP address')),
     'muc_moderated': (
@@ -68,11 +70,11 @@ MUC_FEATURES = {
         _('Participants entering this group chat are '
           'allowed to send messages')),
     'muc_public': (
-        'feather-eye-symbolic',
+        'lucide-megaphone-symbolic',
         p_('Group chat feature', 'Public'),
         _('Group chat can be found via search')),
     'muc_hidden': (
-        'feather-eye-off-symbolic',
+        'lucide-megaphone-off-symbolic',
         p_('Group chat feature', 'Hidden'),
         _('This group chat can not be found via search')),
     'muc_passwordprotected': (
@@ -125,6 +127,7 @@ class GroupChatInfoScrolled(Gtk.ScrolledWindow):
                             Gtk.PolicyType.AUTOMATIC)
 
         self._account = account
+        self._contact: GroupchatContact | None = None
         self._info: DiscoInfo | None = None
 
         self._ui = get_builder('groupchat_info_scrolled.ui')
@@ -139,6 +142,8 @@ class GroupChatInfoScrolled(Gtk.ScrolledWindow):
         self._account = account
 
     def get_jid(self) -> JID | None:
+        if self._contact is not None:
+            return self._contact.jid
         return self._info.jid
 
     def set_subject(self, muc_subject: MucSubject | None) -> None:
@@ -161,6 +166,17 @@ class GroupChatInfoScrolled(Gtk.ScrolledWindow):
         self._ui.subject.set_visible(has_subject)
         self._ui.subject_label.set_visible(has_subject)
 
+    def set_info_from_contact(self, contact: GroupchatContact) -> None:
+        self._contact = contact
+        disco_info = contact.get_disco()
+        if disco_info is not None:
+            self.set_from_disco_info(disco_info)
+            return
+
+        self._ui.address.set_text(str(contact.jid))
+        self._ui.address.set_tooltip_text(str(contact.jid))
+        self._ui.address_copy_button.set_sensitive(True)
+
     def set_from_disco_info(self, info: DiscoInfo) -> None:
         self._info = info
         # Set name
@@ -188,6 +204,7 @@ class GroupChatInfoScrolled(Gtk.ScrolledWindow):
         # Set address
         self._ui.address.set_text(str(info.jid))
         self._ui.address.set_tooltip_text(str(info.jid))
+        self._ui.address_copy_button.set_sensitive(True)
 
         if self._minimal:
             return
@@ -257,8 +274,12 @@ class GroupChatInfoScrolled(Gtk.ScrolledWindow):
         grid.show_all()
 
     def _on_copy_address(self, _button: Gtk.Button) -> None:
+        if self._contact is not None:
+            jid = self._contact.jid
+        else:
+            jid = self._info.jid
         clipboard = Gtk.Clipboard.get(Gdk.SELECTION_CLIPBOARD)
-        clipboard.set_text(self._info.jid.to_iri(XmppUriQuery.JOIN.value), -1)
+        clipboard.set_text(jid.to_iri(XmppUriQuery.JOIN.value), -1)
 
     @staticmethod
     def _on_activate_log_link(button: Gtk.LinkButton) -> int:
