@@ -27,8 +27,6 @@
 from __future__ import annotations
 
 from typing import Any
-from typing import Optional
-from typing import Union
 
 import logging
 import sys
@@ -52,6 +50,7 @@ from gajim.common.ged import EventHelper
 from gajim.common.helpers import allow_showing_notification
 from gajim.common.helpers import play_sound
 from gajim.common.i18n import _
+from gajim.common.modules.contacts import ResourceContact
 
 from gajim.gtk.builder import get_builder
 from gajim.gtk.structs import AccountJidParam
@@ -64,10 +63,10 @@ log = logging.getLogger('gajim.gtk.notification')
 
 
 NOTIFICATION_ICONS: dict[str, str] = {
-    'incoming-message': 'gajim-chat_msg_recv',
-    'group-chat-invitation': 'gajim-gc_invitation',
+    'incoming-message': 'gajim-chat-msg-recv',
+    'group-chat-invitation': 'gajim-group-chat-invitation',
     'incoming-call': 'call-start-symbolic',
-    'subscription_request': 'gajim-subscription_request',
+    'subscription_request': 'gajim-subscription-request',
     'unsubscribed': 'gajim-unsubscribed',
     'file-request-received': 'document-send',
     'file-send-error': 'dialog-error',
@@ -83,7 +82,8 @@ class NotificationBackend(EventHelper):
 
         self.register_events([
             ('notification', ged.GUI2, self._on_notification),
-            ('account-enabled', ged.GUI2, self._on_account_enabled)
+            ('account-enabled', ged.GUI2, self._on_account_enabled),
+            ('chat-read', ged.GUI2, self._on_chat_read)
         ])
 
         for client in app.get_clients():
@@ -111,6 +111,9 @@ class NotificationBackend(EventHelper):
         client = app.get_client(event.account)
         client.connect_signal('state-changed', self._on_client_state_changed)
 
+    def _on_chat_read(self, event: events.ChatRead) -> None:
+        self._withdraw(['new-message', event.account, event.jid])
+
     def _on_client_state_changed(self,
                                  client: Client,
                                  _signal_name: str,
@@ -179,7 +182,7 @@ class PopupNotification(Gtk.Window):
         self.set_decorated(False)
         self.set_keep_above(True)
 
-        self._timeout_id: Optional[int] = None
+        self._timeout_id: int | None = None
         self._event = event
 
         self._ui = get_builder('popup_notification_window.ui')
@@ -217,7 +220,7 @@ class PopupNotification(Gtk.Window):
         if event.icon_name is not None:
             return event.icon_name
         icon_name = event.sub_type or event.type
-        return NOTIFICATION_ICONS.get(icon_name, 'gajim-chat_msg_recv')
+        return NOTIFICATION_ICONS.get(icon_name, 'gajim-chat-msg-recv')
 
     def _add_background_color(self, event: events.Notification) -> None:
         event_type = event.sub_type or event.type
@@ -380,7 +383,7 @@ class Linux(NotificationBackend):
                 _('Mark as Read'), action, params.to_variant())
 
     def _make_notification_id(self,
-                              event: events.Notification) -> Optional[str]:
+                              event: events.Notification) -> str | None:
         if event.type in ('connection-failed', 'server-shutdown'):
             return self._make_id([event.type, event.account])
 
@@ -415,11 +418,12 @@ class Linux(NotificationBackend):
 
 
 def _get_avatar_for_notification(account: str,
-                                 jid: Union[JID, str]) -> GdkPixbuf.Pixbuf:
+                                 jid: JID | str) -> GdkPixbuf.Pixbuf:
     scale = get_monitor_scale_factor()
     size = AvatarSize.NOTIFICATION
     client = app.get_client(account)
     contact = client.get_module('Contacts').get_contact(jid)
+    assert not isinstance(contact, ResourceContact)
     surface = contact.get_avatar(size, scale)
     pixbuf = Gdk.pixbuf_get_from_surface(surface,
                                          0,
