@@ -43,6 +43,7 @@ from nbxmpp import util as nbxmpp_util
 from nbxmpp.structs import LocationData
 from nbxmpp.structs import TuneData
 from PIL import Image
+from PIL import UnidentifiedImageError
 
 from gajim.common import app
 from gajim.common import configpaths
@@ -164,7 +165,7 @@ def get_total_screen_geometry() -> tuple[int, int]:
     display = Gdk.Display.get_default()
     assert display is not None
     monitors = display.get_n_monitors()
-    for num in range(0, monitors):
+    for num in range(monitors):
         monitor = display.get_monitor(num)
         assert monitor is not None
         geometry = monitor.get_geometry()
@@ -619,7 +620,7 @@ def load_pixbuf(path: str | Path,
             with open(path, 'rb') as im_handle:
                 img = Image.open(im_handle)
                 avatar = img.convert('RGBA')
-        except (NameError, OSError):
+        except (NameError, OSError, UnidentifiedImageError):
             log.warning('Pillow convert failed: %s', path)
             log.debug('Error', exc_info=True)
             return None
