@@ -88,6 +88,7 @@ function install_deps {
         "${MINGW_PACKAGE_PREFIX}"-gstreamer \
         "${MINGW_PACKAGE_PREFIX}"-gst-plugins-base \
         "${MINGW_PACKAGE_PREFIX}"-gst-plugins-good \
+        "${MINGW_PACKAGE_PREFIX}"-gst-plugins-bad \
         "${MINGW_PACKAGE_PREFIX}"-gst-libav \
         "${MINGW_PACKAGE_PREFIX}"-gst-python \
         "${MINGW_PACKAGE_PREFIX}"-adwaita-icon-theme \
@@ -171,6 +172,8 @@ function cleanup_install {
         "${MINGW_PACKAGE_PREFIX}"-python-pip "${MINGW_PACKAGE_PREFIX}"-ncurses || true
     build_pacman --noconfirm -Rdd "${MINGW_PACKAGE_PREFIX}"-tk || true
     build_pacman --noconfirm -Rdd "${MINGW_PACKAGE_PREFIX}"-tcl || true
+    build_pacman --noconfirm -Rdd "${MINGW_PACKAGE_PREFIX}"-frei0r-plugins || true
+    build_pacman --noconfirm -Rdd "${MINGW_PACKAGE_PREFIX}"-abseil-cpp || true
 
     #delete translations we don't support
     for d in "${MINGW_ROOT}"/share/locale/*/LC_MESSAGES; do
